@@ -5,7 +5,7 @@ from pymultirole_plugins.v1.schema import Document, DocumentList
 
 from pyprocessors_pseudonimizer.pseudonimizer import (
     PseudonimizerProcessor,
-    PseudonimizerParameters
+    PseudonimizerParameters, OPERATOR_IDENTITY_STR
 )
 
 
@@ -20,6 +20,15 @@ def test_normalize():
         doc = Document(**jdoc)
         formatter = PseudonimizerProcessor()
         options = PseudonimizerParameters()
+        options.mapping = {
+            'wikidata': OPERATOR_IDENTITY_STR,
+            'afporganization': json.dumps({
+                "type": "mask",
+                "masking_char": "X",
+                "chars_to_mask": 3,
+                "from_end": False,
+            })
+        }
         anonymizeds = formatter.process([doc], options)
         norm_file = testdir / "data/afp_ner_fr-document-test-anon.json"
         dl = DocumentList(__root__=anonymizeds)
